#ifndef _DEVICE_CONST_
#define _DEVICE_CONST_

class DeviceType
{
public:
	// device types
	// numbers 1000..3999 reserved (see mainw.h)
	// change TYPE_CNT to the no of entries or die with core

	static const int fBASE = 1000;	// do not change!

	static const int fAND = 1000;
	static const int fOR = 1001;
	static const int fONE = 1002;
	static const int fXOR = 1003;
	static const int fSS = 1004;
	static const int fSWI = 1005;
	static const int fOSC = 1006;
	static const int fINV_INTERNAL = 1007;
	static const int fRS = 1008;
	static const int fDFF = 1009;
	static const int fJK = 1010;
	static const int fLED = 1011;
	static const int fIN = 1012;
	static const int fOUT = 1013;
	static const int fNET = 1014;
	static const int fPWR = 1015;
	static const int fTXT = 1016;
	static const int fEQU = 1017;
	static const int fLED1 = 1018;
	static const int fLED2 = 1019;
	static const int fLED3 = 1020;
	static const int fTRI = 1021;
	static const int fRAM = 1022;
	static const int fBUS = 1023;
	static const int fMATRIX = 1024;	// not active - difficult to implement
	static const int fTFF = 1025;
	static const int fNAND = 1026;		// fAND is used!
	static const int fNOR = 1027;		// fOR is used!

	static const int TYPE_CNT = 26;	// no of entries above!

	static const int fFIRST_LIBDEV = 2000;
	static const int fLAST_LIBDEV = 2999;
};

#endif
